<?php

namespace App\Controller\OgAgent;

use App\Entity\Client;
use App\Model\OgLiveStatus;
use Doctrine\ORM\EntityManagerInterface;
use Symfony\Bundle\FrameworkBundle\Controller\AbstractController;
use Symfony\Component\HttpClient\HttpClient;
use Symfony\Component\HttpClient\Internal\ClientState;
use Symfony\Component\HttpFoundation\JsonResponse;
use Symfony\Component\HttpFoundation\Response;
use Symfony\Component\HttpKernel\Attribute\AsController;
use Symfony\Component\Validator\Exception\ValidatorException;
use Symfony\Contracts\HttpClient\Exception\ClientExceptionInterface;
use Symfony\Contracts\HttpClient\Exception\RedirectionExceptionInterface;
use Symfony\Contracts\HttpClient\Exception\ServerExceptionInterface;
use Symfony\Contracts\HttpClient\Exception\TransportExceptionInterface;
use Symfony\Contracts\HttpClient\HttpClientInterface;

#[AsController]
class StatusAction extends AbstractController
{
    public function __construct(
        protected readonly EntityManagerInterface $entityManager,
        protected readonly HttpClientInterface $httpClient
    )
    {
        $httpClient = HttpClient::create([
            'verify_peer' => false,
            'verify_host' => false,
        ]);
    }

    /**
     * @throws TransportExceptionInterface
     * @throws ServerExceptionInterface
     * @throws RedirectionExceptionInterface
     * @throws ClientExceptionInterface
     */
    public function __invoke(Client $client): JsonResponse
    {
        if (!$client->getIp()) {
            throw new ValidatorException('IP is required');
        }

        try {
            $response = $this->httpClient->request('POST', 'https://'.$client->getIp().':8000/ogAdmClient/status');
            $client->setStatus('off');
            $this->entityManager->persist($client);
            $this->entityManager->flush();
        } catch (TransportExceptionInterface $e) {
            return new JsonResponse( data: 'An error occurred', status: Response::HTTP_INTERNAL_SERVER_ERROR);
        }


        $client->setStatus('active');
        $this->entityManager->persist($client);
        $this->entityManager->flush();

        return new JsonResponse(status: Response::HTTP_OK);
    }
}